@@ -31,6 +31,7 @@ class Clock():
         self.fill = False
         self.show_seconds = True
 
+        self.resize_requested = False
         self.font_name = "Sans"
 
         self.color_r = 1.0
@@ -42,8 +43,14 @@ class Clock():
     def draw(self):
         self.time = datetime.today()
         self.context = self.drawing_area.window.cairo_create()
-
         self.context.select_font_face(self.font_name, cairo.FONT_SLANT_NORMAL, cairo.FONT_WEIGHT_NORMAL)
+        if self.resize_requested :
+            self.resize()
+            if self.alarm_enabled :
+                self.resize_alarm_enabled()
+
+            self.resize_requested = False
+
         self.context.set_source_rgba(1.0, 1.0, 1.0, 0.0)
         self.context.set_operator(cairo.OPERATOR_SOURCE)
         self.context.paint()
@@ -95,13 +102,16 @@ class Clock():
         size = self.drawing_area.get_size_request()
         self.drawing_area.set_size_request(size[0] + 18, size[1])
 
+    def request_resize(self):
+        self.resize_requested = True
+
     def set_alarm_enabled(self, b):
         if (not self.alarm_enabled) and b and self.alarm_indicator_enabled :
             self.alarm_enabled = b
-            self.resize_alarm_enabled()
         else :
             self.alarm_enabled = False
-            self.resize()
+
+        self.request_resize()
 
     def set_alarm_indicator_enabled(self, b):
         self.alarm_indicator_enabled = b
