@@ -19,7 +19,6 @@ import cairo
 from datetime import datetime
 import gtk
 import math
-import pango
 
 import clock
 
@@ -57,12 +56,7 @@ class AlarmDisplayClock(clock.Clock):
 
         if self.twelve_hour_mode :
             self.context.set_font_size(10)
-
-
-            if self.show_seconds :
-                self.context.move_to(self.char_width * 9, 16 if self.alarm_enabled else 26)
-            else :
-                self.context.move_to(self.char_width * 6, 16 if self.alarm_enabled else 26)
+            self.context.move_to(self.text_width, 16 if self.alarm_enabled else 26)
             
             self.context.text_path(abrv)
 
@@ -99,11 +93,7 @@ class AlarmDisplayClock(clock.Clock):
 
             if self.twelve_hour_mode :
                 self.context.set_font_size(10)
-
-                if self.show_seconds :
-                    self.context.move_to(self.char_width * 9, 35)
-                else :
-                    self.context.move_to(self.char_width * 6, 35)
+                self.context.move_to(self.text_width, 35)
             
                 self.context.text_path(abrv)
 
@@ -119,19 +109,21 @@ class AlarmDisplayClock(clock.Clock):
         pass
 
     def resize(self):
-        ctx = self.drawing_area.create_pango_context()
-        fdesc = pango.FontDescription(self.font_name + " 20")  
-        metric = ctx.get_metrics(fdesc)
-        self.char_width = int(metric.get_approximate_digit_width() / pango.SCALE * 0.7)
+        self.context.set_font_size(20)
+        if self.show_seconds :
+            self.text_width = self.context.text_extents("00:00:00")[2]
+        else:
+            self.text_width = self.context.text_extents("00:00")[2]
+
+        self.text_width *= 1.1
 
         if self.twelve_hour_mode :
-            if self.show_seconds :
-                self.drawing_area.set_size_request(self.char_width * 11, 36)
-            else:
-                self.drawing_area.set_size_request(self.char_width * 9, 36)
+            self.text_width += self.context.text_extents("..")[2]
+            self.context.set_font_size(10)
+            self.abrv_width = self.context.text_extents("AM")[2]
+            self.abrv_width *= 1.1
         else :
-            if self.show_seconds :
-                self.drawing_area.set_size_request(self.char_width * 9, 36)
-            else:
-                self.drawing_area.set_size_request(self.char_width * 6, 36)
+            self.abrv_width = 0
+
+        self.drawing_area.set_size_request(int(self.text_width + self.abrv_width), 36)
 
